@@ -12,8 +12,6 @@ from octoprint_nanny.events import try_handle_event
 from octoprint_nanny.utils.printnanny_os import (
     issue_txt,
     load_printnanny_config,
-    janus_edge_hostname,
-    janus_edge_api_token,
     etc_os_release,
     is_printnanny_os,
 )
@@ -115,8 +113,13 @@ class OctoPrintNannyPlugin(
 
     ##~~ SettingsPlugin mixin
     def get_settings_defaults(self):
-        janusApiUrl = "http://{}:8088/janus".format(socket.gethostname())
-        janusApiToken = janus_edge_api_token()
+        config = load_printnanny_config()
+        janusApiUrl = (
+            config.get("config", {}).get("janus_edge", {}).get("api_http_url", "")
+        )
+        janusApiToken = (
+            config.get("config", {}).get("janus_edge", {}).get("api_token", "")
+        )
 
         DEFAULT_SETTINGS = dict(
             janusApiUrl=janusApiUrl,
@@ -136,8 +139,6 @@ class OctoPrintNannyPlugin(
                 "discord_invite": "https://discord.gg/sf23bk2hPr",
                 "webapp": PRINTNANNY_WEBAPP_BASE_URL,
             },
-            "janus_edge_hostname": janus_edge_hostname(),
-            "janus_edge_api_token": janus_edge_api_token(),
             "issue_txt": issue_txt(),
             "etc_os_release": etc_os_release(),
             "config": load_printnanny_config(),
