@@ -26,23 +26,32 @@
 //     });
 // });
 
-/*
-** 
-** Helpers
-**
-*/
+$(function () {
+    function CameraWarningViewModel(parameters) {
+
+        $('#settings_webcam h3:first-of-type').after('<div class="alert alert-printnanny alert-block"><h4 class="alert-heading">Note from PrintNanny</h4><p>The setting below do not apply to PrintNanny\'s web camera!</p><p> Use PrintNanny\'s Camera settings tab instead. </p><p><a data-toggle="tab" href="#settings_plugin_octoprint_nanny" class="btn btn-primary">Open PrintNanny Settings</a></p></div>')
+    }
+
+    OCTOPRINT_VIEWMODELS.push({
+        construct: CameraWarningViewModel,
+        dependencies: ["loginStateViewModel", "settingsViewModel"],
+        elements: ["#settings_webcam"]
+    });
+});
 
 $(function () {
-    function PrintNannyTabViewModel(parameters) {
+    function PrintNannyNavbarViewModel(parameters) {
         let self = this;
+        self.loginState = parameters[0];
+        self.settings = parameters[1];
 
         self.showError = ko.observable(false);
         self.showStart = ko.observable(true);
         self.disableStart = ko.observable(false);
         self.errorMessages = ko.observableArray([])
-        self.onAfterBinding = function () {
-            initializeJanus(self)
-        }
+        // self.onAfterBinding = function () {
+        //     initializeJanus(self)
+        // }
 
         self.error = function (msg) {
             console.error(msg);
@@ -61,43 +70,14 @@ $(function () {
             OctoPrint.socket.sendMessage("plugin_octoprint_nanny_nnstreamer_stop");
             stopStream();
         }
-
-        // TODO enable pass messages to vue app
-        // OctoPrint.socket.onMessage("*", function (message) {
-        //     console.log(message);
-        // })
-    }
-
-    PrintNannyTabViewModel.prototype.koDescendantsComplete = function (node) {
-        $vm.$forceUpdate();
     }
 
     OCTOPRINT_VIEWMODELS.push({
-        construct: PrintNannyTabViewModel,
+        construct: PrintNannyNavbarViewModel,
         // ViewModels your plugin depends on, e.g. loginStateViewModel, settingsViewModel, ...
         dependencies: ["loginStateViewModel", "settingsViewModel"],
         // Elements to bind to, e.g. #settings_plugin_nanny, #tab_plugin_nanny, ...
-        elements: ['#tab_plugin_octoprint_nanny', '#navbar_plugin_octoprint_nanny']
-
-    });
-});
-
-
-$(function () {
-    function PrintNannySettingsViewModel(parameters) {
-
-        let self = this;
-
-    }
-
-
-
-    OCTOPRINT_VIEWMODELS.push({
-        construct: PrintNannySettingsViewModel,
-        // ViewModels your plugin depends on, e.g. loginStateViewModel, settingsViewModel, ...
-        dependencies: ["loginStateViewModel", "settingsViewModel"],
-        // Elements to bind to, e.g. #settings_plugin_nanny, #tab_plugin_nanny, ...
-        elements: ['#settings_plugin_octoprint_nanny', '#wizard_plugin_octoprint_nanny']
+        elements: ['#navbar_plugin_octoprint_nanny']
 
     });
 });
